@@ -13,6 +13,9 @@ class CommonTestCase(unittest.TestCase):
             "VAR2": "value2",
             "TSURU_APPNAME": "appname1",
             "TSURU_HOST": "host1",
+            "TSURU_SYSLOG_SERVER": "host2",
+            "TSURU_SYSLOG_PORT": "514",
+            "TSURU_SYSLOG_FACILITY": "LOCAL0"
         }
         got = common.load_envs(path)
         self.assertEqual(want, got)
